==> bigloo3.4a-3.tar.gz: bigloo3.4a-3/comptime/SawMill/elsewhere.c <==
/*===========================================================================*/
/*   (SawMill/elsewhere.scm)                                                 */
/*   Bigloo (3.4a)                                                           */
/*   Inria -- Sophia Antipolis (c)       Thu Jul 1 12:14:45 CEST 2010        */
/*===========================================================================*/
/* COMPILATION: (/users/serrano/prgm/project/bigloo/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /users/serrano/prgm/project/bigloo/lib/3.4a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -indent SawMill/elsewhere.scm)*/
/* GC selection */
#define THE_GC BOEHM_GC

#include <bigloo.h>

#ifdef __cplusplus
extern "C"
{
#endif

/* Object type definitions */
	typedef struct BgL_valuez00_bgl
	{
		header_t header;
		obj_t widening;
	}               *BgL_valuez00_bglt;

	typedef struct BgL_variablez00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_idz00;
		obj_t BgL_namez00;
		struct BgL_typez00_bgl *BgL_typez00;
		struct BgL_valuez00_bgl *BgL_valuez00;
		obj_t BgL_accessz00;
		obj_t BgL_fastzd2alphazd2;
		obj_t BgL_removablez00;
		long BgL_occurrencez00;
	}                  *BgL_variablez00_bglt;

	typedef struct BgL_globalz00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_idz00;
		obj_t BgL_namez00;
		struct BgL_typez00_bgl *BgL_typez00;
		struct BgL_valuez00_bgl *BgL_valuez00;
		obj_t BgL_accessz00;
		obj_t BgL_fastzd2alphazd2;
		obj_t BgL_removablez00;
		long BgL_occurrencez00;
		obj_t BgL_modulez00;
		obj_t BgL_importz00;
		bool_t BgL_evaluablezf3zf3;
		obj_t BgL_libraryz00;
		bool_t BgL_userzf3zf3;
		obj_t BgL_pragmaz00;
		obj_t BgL_srcz00;
		obj_t BgL_jvmzd2typezd2namez00;
	}                *BgL_globalz00_bglt;

	typedef struct BgL_scnstz00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_nodez00;
		obj_t BgL_classz00;
		obj_t BgL_locz00;
	}               *BgL_scnstz00_bglt;


	BGL_IMPORT obj_t BGl_readz00zz__readerz00(obj_t, obj_t);
	extern obj_t BGl_za2moduleza2z00zzmodule_modulez00;
	static obj_t BGl_cnstzd2initzd2zzsaw_elsewherez00();
	BGL_EXPORTED_DECL obj_t
		BGl_needzd2functionzd2pointerz00zzsaw_elsewherez00(BgL_globalz00_bglt);
	BGL_EXPORTED_DECL obj_t
		BGl_modulezd2initializa7ationz75zzsaw_elsewherez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzbackend_c_prototypez00(long,
		char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzmodule_modulez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_nodez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_varz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztype_typez00(long, char *);
	BGL_IMPORT obj_t
		BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__readerz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__objectz00(long, char *);
	BGL_IMPORT obj_t BGl_memqz00zz__r4_pairs_and_lists_6_3z00(obj_t, obj_t);
	static obj_t BGl_methodzd2initzd2zzsaw_elsewherez00();
	BGL_IMPORT bool_t BGl_iszd2azf3z21zz__objectz00(obj_t, obj_t);
	static obj_t BGl_requirezd2initializa7ationz75zzsaw_elsewherez00 = BUNSPEC;
	extern obj_t BGl_scnstz00zzast_varz00;
	static obj_t BGl_genericzd2initzd2zzsaw_elsewherez00();
	static obj_t BGl_importedzd2moduleszd2initz00zzsaw_elsewherez00();
	BGL_IMPORT obj_t bgl_open_input_string(obj_t, int);
	extern bool_t
		BGl_requirezd2prototypezf3z21zzbackend_c_prototypez00(BgL_globalz00_bglt);
	static obj_t BGl__needzd2functionzd2pointerz00zzsaw_elsewherez00(obj_t,
		obj_t);
	static obj_t BGl_libraryzd2moduleszd2initz00zzsaw_elsewherez00();
	static obj_t __cnst[1];


	   
		 
		DEFINE_EXPORT_BGL_PROCEDURE
		(BGl_needzd2functionzd2pointerzd2envzd2zzsaw_elsewherez00,
		BgL_bgl__needza7d2function3222za7,
		BGl__needzd2functionzd2pointerz00zzsaw_elsewherez00, 0L, BUNSPEC, 1);
	      DEFINE_STRING(BGl_string3217z00zzsaw_elsewherez00,
		BgL_bgl_string3217za700za7za7s3223za7, "saw_elsewhere", 13);
	      DEFINE_STRING(BGl_string3218z00zzsaw_elsewherez00,
		BgL_bgl_string3218za700za7za7s3224za7, "(sfun sgfun) ", 13);



/* module-initialization */
	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzsaw_elsewherez00(long
		BgL_checksumz00_1151, char *BgL_fromz00_1152)
	{
		AN_OBJECT;
		{
			if (CBOOL(BGl_requirezd2initializa7ationz75zzsaw_elsewherez00))
				{
					BGl_requirezd2initializa7ationz75zzsaw_elsewherez00 =
						BBOOL(((bool_t) 0));
					BGl_libraryzd2moduleszd2initz00zzsaw_elsewherez00();
					BGl_cnstzd2initzd2zzsaw_elsewherez00();
					BGl_importedzd2moduleszd2initz00zzsaw_elsewherez00();
					return BUNSPEC;
				}
			else
				{
					return BUNSPEC;
				}
		}
	}



/* library-modules-init */
	obj_t BGl_libraryzd2moduleszd2initz00zzsaw_elsewherez00()
	{
		AN_OBJECT;
		{	/* SawMill/elsewhere.scm 1 */
			BGl_modulezd2initializa7ationz75zz__readerz00(((long) 0),
				"saw_elsewhere");
			BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(((long) 0),
				"saw_elsewhere");
			BGl_modulezd2initializa7ationz75zz__objectz00(((long) 0),
				"saw_elsewhere");
			return BUNSPEC;
		}
	}



/* cnst-init */
	obj_t BGl_cnstzd2initzd2zzsaw_elsewherez00()
	{
		AN_OBJECT;
		{	/* SawMill/elsewhere.scm 1 */
			{	/* SawMill/elsewhere.scm 1 */
				obj_t BgL_cportz00_1143;

				BgL_cportz00_1143 =
					bgl_open_input_string(BGl_string3218z00zzsaw_elsewherez00,
					(int) (((long) 0)));
				{
					long BgL_iz00_1144;

					BgL_iz00_1144 = ((long) 0);
				BgL_loopz00_1145:
					if ((BgL_iz00_1144 == ((long) -1)))
						{	/* SawMill/elsewhere.scm 1 */
							return BUNSPEC;
						}
					else
						{	/* SawMill/elsewhere.scm 1 */
							{	/* SawMill/elsewhere.scm 1 */
								obj_t BgL_arg3221z00_1147;

								{	/* SawMill/elsewhere.scm 1 */

									{	/* SawMill/elsewhere.scm 1 */
										obj_t BgL_locationz00_1149;

										BgL_locationz00_1149 = BBOOL(((bool_t) 0));
										{	/* SawMill/elsewhere.scm 1 */

											BgL_arg3221z00_1147 =
												BGl_readz00zz__readerz00(BgL_cportz00_1143,
												BgL_locationz00_1149);
										}
									}
								}
								{	/* SawMill/elsewhere.scm 1 */
									int BgL_auxz00_1168;

									BgL_auxz00_1168 = (int) (BgL_iz00_1144);
									CNST_TABLE_SET(BgL_auxz00_1168, BgL_arg3221z00_1147);
							}}
							{	/* SawMill/elsewhere.scm 1 */
								int BgL_auxz00_1150;

								BgL_auxz00_1150 = (int) ((BgL_iz00_1144 - ((long) 1)));
								{
									long BgL_iz00_1173;

									BgL_iz00_1173 = (long) (BgL_auxz00_1150);
									BgL_iz00_1144 = BgL_iz00_1173;
									goto BgL_loopz00_1145;
								}
							}
						}
				}
			}
		}
	}



/* need-function-pointer */
	BGL_EXPORTED_DEF obj_t
		BGl_needzd2functionzd2pointerz00zzsaw_elsewherez00(BgL_globalz00_bglt
		BgL_varz00_1)
	{
		AN_OBJECT;
		{	/* SawMill/elsewhere.scm 7 */
			{	/* SawMill/elsewhere.scm 8 */
				BgL_valuez00_bglt BgL_valz00_752;

				{
					BgL_variablez00_bglt BgL_auxz00_1175;

					BgL_auxz00_1175 = (BgL_variablez00_bglt) (BgL_varz00_1);
					BgL_valz00_752 =
						(((BgL_variablez00_bglt) CREF(BgL_auxz00_1175))->BgL_valuez00);
				}
				{	/* SawMill/elsewhere.scm 9 */
					bool_t BgL_testz00_1178;

					{	/* SawMill/elsewhere.scm 9 */
						obj_t BgL_arg3168z00_758;

						BgL_arg3168z00_758 =
							(((BgL_globalz00_bglt) CREF(BgL_varz00_1))->BgL_modulez00);
						BgL_testz00_1178 =
							(BgL_arg3168z00_758 == BGl_za2moduleza2z00zzmodule_modulez00);
					}
					if (BgL_testz00_1178)
						{	/* SawMill/elsewhere.scm 9 */
							if (BGl_requirezd2prototypezf3z21zzbackend_c_prototypez00
								(BgL_varz00_1))
								{	/* SawMill/elsewhere.scm 11 */
									bool_t BgL_testz00_1183;

									{	/* SawMill/elsewhere.scm 11 */
										obj_t BgL_obj1956z00_1139;

										BgL_obj1956z00_1139 = (obj_t) (BgL_valz00_752);
										BgL_testz00_1183 =
											BGl_iszd2azf3z21zz__objectz00(BgL_obj1956z00_1139,
											BGl_scnstz00zzast_varz00);
									}
									if (BgL_testz00_1183)
										{	/* SawMill/elsewhere.scm 12 */
											obj_t BgL_auxz00_1186;

											{
												BgL_scnstz00_bglt BgL_auxz00_1187;

												BgL_auxz00_1187 = (BgL_scnstz00_bglt) (BgL_valz00_752);
												BgL_auxz00_1186 =
													(((BgL_scnstz00_bglt) CREF(BgL_auxz00_1187))->
													BgL_classz00);
											}
											return
												BGl_memqz00zz__r4_pairs_and_lists_6_3z00
												(BgL_auxz00_1186, CNST_TABLE_REF(((long) 0)));
										}
									else
										{	/* SawMill/elsewhere.scm 11 */
											return BFALSE;
										}
								}
							else
								{	/* SawMill/elsewhere.scm 10 */
									return BFALSE;
								}
						}
					else
						{	/* SawMill/elsewhere.scm 9 */
							return BFALSE;
						}
				}
			}
		}
	}



/* _need-function-pointer */
	obj_t BGl__needzd2functionzd2pointerz00zzsaw_elsewherez00(obj_t
		BgL_envz00_1141, obj_t BgL_varz00_1142)
	{
		AN_OBJECT;
		{	/* SawMill/elsewhere.scm 7 */
			return
				BGl_needzd2functionzd2pointerz00zzsaw_elsewherez00(
				(BgL_globalz00_bglt) (BgL_varz00_1142));
		}
	}



/* generic-init */
	obj_t BGl_genericzd2initzd2zzsaw_elsewherez00()
	{
		AN_OBJECT;
		{	/* SawMill/elsewhere.scm 1 */
			return BUNSPEC;
		}
	}



/* method-init */
	obj_t BGl_methodzd2initzd2zzsaw_elsewherez00()
	{
		AN_OBJECT;
		{	/* SawMill/elsewhere.scm 1 */
			return BUNSPEC;
		}
	}



/* imported-modules-init */
	obj_t BGl_importedzd2moduleszd2initz00zzsaw_elsewherez00()
	{
		AN_OBJECT;
		{	/* SawMill/elsewhere.scm 1 */
			BGl_modulezd2initializa7ationz75zztype_typez00(((long) 445289072),
				BSTRING_TO_STRING(BGl_string3217z00zzsaw_elsewherez00));
			BGl_modulezd2initializa7ationz75zzast_varz00(((long) 43233168),
				BSTRING_TO_STRING(BGl_string3217z00zzsaw_elsewherez00));
			BGl_modulezd2initializa7ationz75zzast_nodez00(((long) 498112980),
				BSTRING_TO_STRING(BGl_string3217z00zzsaw_elsewherez00));
			BGl_modulezd2initializa7ationz75zzmodule_modulez00(((long) 358171001),
				BSTRING_TO_STRING(BGl_string3217z00zzsaw_elsewherez00));
			return
				BGl_modulezd2initializa7ationz75zzbackend_c_prototypez00(((long)
					14608757), BSTRING_TO_STRING(BGl_string3217z00zzsaw_elsewherez00));
		}
	}

#ifdef __cplusplus
}
#endif

==> bigloo3.7a-2.tar.gz: bigloo3.7a-2/comptime/SawMill/elsewhere.c <==
/*===========================================================================*/
/*   (SawMill/elsewhere.scm)                                                 */
/*   Bigloo (3.7a)                                                           */
/*   Inria -- Sophia Antipolis (c)       Wed Sep 28 13:05:28 CEST 2011       */
/*===========================================================================*/
/* COMPILATION: (/users/serrano/prgm/project/bigloo/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /users/serrano/prgm/project/bigloo/lib/3.7a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -indent SawMill/elsewhere.scm)*/
/* GC selection */
#define THE_GC BOEHM_GC

#include <bigloo.h>

#ifdef __cplusplus
extern "C"
{
#endif

/* Object type definitions */
	typedef struct BgL_valuez00_bgl
	{
		header_t header;
		obj_t widening;
	}               *BgL_valuez00_bglt;

	typedef struct BgL_variablez00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_idz00;
		obj_t BgL_namez00;
		struct BgL_typez00_bgl *BgL_typez00;
		struct BgL_valuez00_bgl *BgL_valuez00;
		obj_t BgL_accessz00;
		obj_t BgL_fastzd2alphazd2;
		obj_t BgL_removablez00;
		long BgL_occurrencez00;
		long BgL_occurrencewz00;
		bool_t BgL_userzf3zf3;
	}                  *BgL_variablez00_bglt;

	typedef struct BgL_globalz00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_idz00;
		obj_t BgL_namez00;
		struct BgL_typez00_bgl *BgL_typez00;
		struct BgL_valuez00_bgl *BgL_valuez00;
		obj_t BgL_accessz00;
		obj_t BgL_fastzd2alphazd2;
		obj_t BgL_removablez00;
		long BgL_occurrencez00;
		long BgL_occurrencewz00;
		bool_t BgL_userzf3zf3;
		obj_t BgL_modulez00;
		obj_t BgL_importz00;
		bool_t BgL_evaluablezf3zf3;
		bool_t BgL_evalzf3zf3;
		obj_t BgL_libraryz00;
		obj_t BgL_pragmaz00;
		obj_t BgL_srcz00;
		obj_t BgL_jvmzd2typezd2namez00;
		obj_t BgL_initz00;
	}                *BgL_globalz00_bglt;

	typedef struct BgL_scnstz00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_nodez00;
		obj_t BgL_classz00;
		obj_t BgL_locz00;
	}               *BgL_scnstz00_bglt;


	BGL_IMPORT bool_t BGl_iszd2azf3z21zz__objectz00(obj_t, obj_t);
	BGL_IMPORT obj_t BGl_memqz00zz__r4_pairs_and_lists_6_3z00(obj_t, obj_t);
	static obj_t BGl_methodzd2initzd2zzsaw_elsewherez00();
	BGL_EXPORTED_DECL obj_t
		BGl_needzd2functionzd2pointerz00zzsaw_elsewherez00(BgL_globalz00_bglt);
	static obj_t BGl_requirezd2initializa7ationz75zzsaw_elsewherez00 = BUNSPEC;
	static obj_t BGl_z62needzd2functionzd2pointerz62zzsaw_elsewherez00(obj_t,
		obj_t);
	static obj_t BGl_genericzd2initzd2zzsaw_elsewherez00();
	BGL_IMPORT obj_t BGl_readz00zz__readerz00(obj_t, obj_t);
	extern obj_t BGl_za2moduleza2z00zzmodule_modulez00;
	BGL_EXPORTED_DECL obj_t
		BGl_modulezd2initializa7ationz75zzsaw_elsewherez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzbackend_c_prototypez00(long,
		char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzmodule_modulez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_nodez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_varz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztype_typez00(long, char *);
	BGL_IMPORT obj_t
		BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__readerz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__objectz00(long, char *);
	static obj_t BGl_cnstzd2initzd2zzsaw_elsewherez00();
	static obj_t BGl_libraryzd2moduleszd2initz00zzsaw_elsewherez00();
	extern bool_t
		BGl_requirezd2prototypezf3z21zzbackend_c_prototypez00(BgL_globalz00_bglt);
	static obj_t BGl_importedzd2moduleszd2initz00zzsaw_elsewherez00();
	extern obj_t BGl_scnstz00zzast_varz00;
	BGL_IMPORT obj_t bgl_open_input_string(obj_t, int);
	static obj_t __cnst[1];


	   
		 
		DEFINE_STRING(BGl_string3446z00zzsaw_elsewherez00,
		BgL_bgl_string3446za700za7za7s3452za7, "saw_elsewhere", 13);
	      DEFINE_STRING(BGl_string3447z00zzsaw_elsewherez00,
		BgL_bgl_string3447za700za7za7s3453za7, "(sfun sgfun slfun) ", 19);
	     
		DEFINE_EXPORT_BGL_PROCEDURE
		(BGl_needzd2functionzd2pointerzd2envzd2zzsaw_elsewherez00,
		BgL_bgl_za762needza7d2functi3454z00,
		BGl_z62needzd2functionzd2pointerz62zzsaw_elsewherez00, 0L, BUNSPEC, 1);



/* module-initialization */
	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzsaw_elsewherez00(long
		BgL_checksumz00_1260, char *BgL_fromz00_1261)
	{
		AN_OBJECT;
		{
			if (CBOOL(BGl_requirezd2initializa7ationz75zzsaw_elsewherez00))
				{
					BGl_requirezd2initializa7ationz75zzsaw_elsewherez00 =
						BBOOL(((bool_t) 0));
					BGl_libraryzd2moduleszd2initz00zzsaw_elsewherez00();
					BGl_cnstzd2initzd2zzsaw_elsewherez00();
					BGl_importedzd2moduleszd2initz00zzsaw_elsewherez00();
					return BUNSPEC;
				}
			else
				{
					return BUNSPEC;
				}
		}
	}



/* library-modules-init */
	obj_t BGl_libraryzd2moduleszd2initz00zzsaw_elsewherez00()
	{
		AN_OBJECT;
		{	/* SawMill/elsewhere.scm 1 */
			BGl_modulezd2initializa7ationz75zz__objectz00(((long) 0),
				"saw_elsewhere");
			BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(((long) 0),
				"saw_elsewhere");
			BGl_modulezd2initializa7ationz75zz__readerz00(((long) 0),
				"saw_elsewhere");
			return BUNSPEC;
		}
	}



/* cnst-init */
	obj_t BGl_cnstzd2initzd2zzsaw_elsewherez00()
	{
		AN_OBJECT;
		{	/* SawMill/elsewhere.scm 1 */
			{	/* SawMill/elsewhere.scm 1 */
				obj_t BgL_cportz00_1252;

				BgL_cportz00_1252 =
					bgl_open_input_string(BGl_string3447z00zzsaw_elsewherez00,
					(int) (((long) 0)));
				{
					long BgL_iz00_1253;

					BgL_iz00_1253 = ((long) 0);
				BgL_loopz00_1254:
					if ((BgL_iz00_1253 == ((long) -1)))
						{	/* SawMill/elsewhere.scm 1 */
							return BUNSPEC;
						}
					else
						{	/* SawMill/elsewhere.scm 1 */
							{	/* SawMill/elsewhere.scm 1 */
								obj_t BgL_arg3451z00_1256;

								{	/* SawMill/elsewhere.scm 1 */

									{	/* SawMill/elsewhere.scm 1 */
										obj_t BgL_locationz00_1258;

										BgL_locationz00_1258 = BBOOL(((bool_t) 0));
										{	/* SawMill/elsewhere.scm 1 */

											BgL_arg3451z00_1256 =
												BGl_readz00zz__readerz00(BgL_cportz00_1252,
												BgL_locationz00_1258);
										}
									}
								}
								{	/* SawMill/elsewhere.scm 1 */
									int BgL_auxz00_1277;

									BgL_auxz00_1277 = (int) (BgL_iz00_1253);
									CNST_TABLE_SET(BgL_auxz00_1277, BgL_arg3451z00_1256);
							}}
							{	/* SawMill/elsewhere.scm 1 */
								int BgL_auxz00_1259;

								BgL_auxz00_1259 = (int) ((BgL_iz00_1253 - ((long) 1)));
								{
									long BgL_iz00_1282;

									BgL_iz00_1282 = (long) (BgL_auxz00_1259);
									BgL_iz00_1253 = BgL_iz00_1282;
									goto BgL_loopz00_1254;
								}
							}
						}
				}
			}
		}
	}



/* need-function-pointer */
	BGL_EXPORTED_DEF obj_t
		BGl_needzd2functionzd2pointerz00zzsaw_elsewherez00(BgL_globalz00_bglt
		BgL_varz00_3)
	{
		AN_OBJECT;
		{	/* SawMill/elsewhere.scm 7 */
			{	/* SawMill/elsewhere.scm 8 */
				BgL_valuez00_bglt BgL_valz00_829;

				{	/* SawMill/elsewhere.scm 8 */
					BgL_variablez00_bglt BgL_obj1612z00_1238;

					BgL_obj1612z00_1238 = ((BgL_variablez00_bglt) BgL_varz00_3);
					BgL_valz00_829 =
						(((BgL_variablez00_bglt) CREF(
								((obj_t) BgL_obj1612z00_1238)))->BgL_valuez00);
				}
				{	/* SawMill/elsewhere.scm 9 */
					bool_t BgL_testz00_1287;

					{	/* SawMill/elsewhere.scm 9 */
						obj_t BgL_arg3396z00_834;

						BgL_arg3396z00_834 =
							(((BgL_globalz00_bglt) CREF(
									((obj_t) BgL_varz00_3)))->BgL_modulez00);
						BgL_testz00_1287 =
							(BgL_arg3396z00_834 == BGl_za2moduleza2z00zzmodule_modulez00);
					}
					if (BgL_testz00_1287)
						{	/* SawMill/elsewhere.scm 9 */
							if (BGl_requirezd2prototypezf3z21zzbackend_c_prototypez00
								(BgL_varz00_3))
								{	/* SawMill/elsewhere.scm 11 */
									bool_t BgL_testz00_1293;

									{	/* SawMill/elsewhere.scm 11 */
										bool_t BgL_res3445z00_1241;

										{	/* SawMill/elsewhere.scm 11 */
											obj_t BgL_obj2095z00_1240;

											BgL_obj2095z00_1240 = ((obj_t) BgL_valz00_829);
											BgL_res3445z00_1241 =
												BGl_iszd2azf3z21zz__objectz00(BgL_obj2095z00_1240,
												BGl_scnstz00zzast_varz00);
										}
										BgL_testz00_1293 = BgL_res3445z00_1241;
									}
									if (BgL_testz00_1293)
										{	/* SawMill/elsewhere.scm 12 */
											obj_t BgL_auxz00_1296;

											{	/* SawMill/elsewhere.scm 12 */
												BgL_scnstz00_bglt BgL_obj2077z00_1242;

												BgL_obj2077z00_1242 =
													((BgL_scnstz00_bglt) BgL_valz00_829);
												BgL_auxz00_1296 =
													(((BgL_scnstz00_bglt) CREF(
															((obj_t) BgL_obj2077z00_1242)))->BgL_classz00);
											}
											return
												BGl_memqz00zz__r4_pairs_and_lists_6_3z00
												(BgL_auxz00_1296, CNST_TABLE_REF(((long) 0)));
										}
									else
										{	/* SawMill/elsewhere.scm 11 */
											return BFALSE;
										}
								}
							else
								{	/* SawMill/elsewhere.scm 10 */
									return BFALSE;
								}
						}
					else
						{	/* SawMill/elsewhere.scm 9 */
							return BFALSE;
						}
				}
			}
		}
	}



/* &need-function-pointer */
	obj_t BGl_z62needzd2functionzd2pointerz62zzsaw_elsewherez00(obj_t
		BgL_envz00_1243, obj_t BgL_varz00_1244)
	{
		AN_OBJECT;
		{	/* SawMill/elsewhere.scm 7 */
			return
				BGl_needzd2functionzd2pointerz00zzsaw_elsewherez00(
				((BgL_globalz00_bglt) BgL_varz00_1244));
		}
	}



/* generic-init */
	obj_t BGl_genericzd2initzd2zzsaw_elsewherez00()
	{
		AN_OBJECT;
		{	/* SawMill/elsewhere.scm 1 */
			return BUNSPEC;
		}
	}



/* method-init */
	obj_t BGl_methodzd2initzd2zzsaw_elsewherez00()
	{
		AN_OBJECT;
		{	/* SawMill/elsewhere.scm 1 */
			return BUNSPEC;
		}
	}



/* imported-modules-init */
	obj_t BGl_importedzd2moduleszd2initz00zzsaw_elsewherez00()
	{
		AN_OBJECT;
		{	/* SawMill/elsewhere.scm 1 */
			BGl_modulezd2initializa7ationz75zztype_typez00(((long) 515343395),
				BSTRING_TO_STRING(BGl_string3446z00zzsaw_elsewherez00));
			BGl_modulezd2initializa7ationz75zzast_varz00(((long) 90839984),
				BSTRING_TO_STRING(BGl_string3446z00zzsaw_elsewherez00));
			BGl_modulezd2initializa7ationz75zzast_nodez00(((long) 353660849),
				BSTRING_TO_STRING(BGl_string3446z00zzsaw_elsewherez00));
			BGl_modulezd2initializa7ationz75zzmodule_modulez00(((long) 158397907),
				BSTRING_TO_STRING(BGl_string3446z00zzsaw_elsewherez00));
			return
				BGl_modulezd2initializa7ationz75zzbackend_c_prototypez00(((long)
					364917963), BSTRING_TO_STRING(BGl_string3446z00zzsaw_elsewherez00));
		}
	}

#ifdef __cplusplus
}
#endif
